window.addEventListener('scroll', function () {
    const header = document.querySelector('header');
    if (header) {
        header.classList.toggle('sticky', window.scrollY > 0);
    }
});

function showLoginForm() {
    document.getElementById('login-form').style.display = 'block';
    document.getElementById('signup-form').style.display = 'none';
}

function showSignupForm() {
    document.getElementById('login-form').style.display = 'none';
    document.getElementById('signup-form').style.display = 'block';
}

document.addEventListener('DOMContentLoaded', function () {
    console.log('DOM Content Loaded');

    document.querySelectorAll('.add-to-cart-btn').forEach(button => {
        button.addEventListener('click', function (e) {
            e.preventDefault();
            const form = this.closest('form');
            const formData = new FormData(form);

            fetch(form.action, {
                method: form.method,
                body: formData,
            })
                .then(response => response.json())
                .then(data => {
                    if (data.success) {
                        alert(data.message);
                    } else {
                        alert('Failed to add to cart. ' + data.message);
                    }
                })
                .catch(error => {
                    console.error('Error:', error);
                    alert('An error occurred while processing your request.');
                });
        });
    });

    document.querySelectorAll('.cart-item').forEach(item => {
        const quantityInput = item.querySelector('input[name="quantity"]');
        const updateButton = item.querySelector('button[type="submit"]');
        const inventoryDisplay = item.querySelector('.available-inventory'); 
        const maxInventory = parseInt(quantityInput.max);

        function updateInventoryDisplay() {
            const newInventory = maxInventory - parseInt(quantityInput.value);
            inventoryDisplay.textContent = `Available Inventory: ${newInventory}`;
        }

        item.querySelector('.increment-btn').addEventListener('click', function () {
            if (quantityInput.value < maxInventory) {
                quantityInput.stepUp();
                updateInventoryDisplay();
            }
            updateButton.disabled = false;
        });

        item.querySelector('.decrement-btn').addEventListener('click', function () {
            if (quantityInput.value > 1) {
                quantityInput.stepDown();
                updateInventoryDisplay();
            }
            updateButton.disabled = false;
        });

        quantityInput.addEventListener('input', function () {
            if (this.value <= maxInventory && this.value >= 1) {
                updateInventoryDisplay();
            }
            updateButton.disabled = false;
        });

        updateButton.addEventListener('click', function (e) {
            e.preventDefault();
            const formData = new FormData(this.form);

            fetch('/update_cart_quantity', {
                method: 'POST',
                body: formData,
            })
            .then(response => response.json())
            .then(data => {
                if (data.success) {
                    alert('Cart updated successfully.');
                    // Update the inventory display with the new inventory value
                    inventoryDisplay.textContent = `Available Inventory: ${data.new_inventory}`;
                } else {
                    alert('Failed to update cart. ' + data.message);
                }
            })
            .catch(error => {
                console.error('Error:', error);
                alert('An error occurred while updating the cart.');
            });
        });
    });

    const navbarLinks = document.querySelectorAll('.nav-link');
    function setActiveLink() {
        const currentSection = window.location.pathname.split('/')[1];
        navbarLinks.forEach(link => {
            const linkSection = link.getAttribute('data-section');
            if (linkSection === currentSection) {
                link.classList.add('active');
            } else {
                link.classList.remove('active');
            }
        });
    }

    setActiveLink();
    window.addEventListener('scroll', setActiveLink);

    document.querySelectorAll('.book-card').forEach(card => {
        console.log('Processing book-card element:', card);

        const stars = card.querySelectorAll('.star');
        stars.forEach(star => {
            star.addEventListener('mouseover', function () {
                updateStars(card, this.getAttribute('data-value'));
            });
            star.addEventListener('mouseout', function () {
                const currentRating = card.getAttribute('data-rating');
                updateStars(card, currentRating);
            });
            star.addEventListener('click', function () {
                const rating = this.getAttribute('data-value');
                const isbn = this.getAttribute('data-isbn');
                updateRating(isbn, rating, 'book-list');
            });
        });
    });

    function updateStars(container, rating) {
        const stars = container.querySelectorAll('.star');
        stars.forEach((star, index) => {
            if (index < rating) {
                star.classList.add('filled');
                star.style.color = 'yellow';
            } else {
                star.classList.remove('filled');
                star.style.color = 'gray';
            }
        });
    }

    function updateRating(isbn, rating, context) {
        let selector = context === 'cart' ? '.cart-item' : '.book-card';
        let container = document.querySelector(selector + '[data-isbn="' + isbn + '"]');
        console.log('Selected container:', container);
    
       
        console.log('Container HTML:', container.innerHTML);
    
        fetch('/update_rating', {
            method: 'POST',
            headers: { 'Content-Type': 'application/json' },
            body: JSON.stringify({ isbn, rating })
        })
        .then(response => response.json())
        .then(data => {
            console.log("Server Response:", data);
    
         
            const avgRatingElement = Array.from(container.getElementsByTagName('p')).find(p => p.innerText.includes('Avg. Rating'));
            console.log('avgRatingElement:', avgRatingElement);
    
            if (avgRatingElement) {
         
                const currentRating = avgRatingElement.innerText.match(/(\d+(\.\d+)?)/);
                const newAvgRating = data.new_avg_rating ? data.new_avg_rating.toFixed(2) : 'N/A';
    
            
                avgRatingElement.innerText = `Avg. Rating: ${newAvgRating} / 5`;
            } else {
                console.error('Error: Avg-rating element not found in the container.');
            }
    
            if (data.success) {
                alert('Rating updated successfully!');
            } else {
                alert('Failed to update rating. ' + data.message);
            }
        })
        .catch(error => {
            console.error('Error:', error);
            alert('An error occurred while updating the rating.');
        });
    }
    
 
    
    
});

window.addEventListener('scroll', function () {
    // Scroll
});



function openReviewModal(isbn) {
   
    fetch(`/get_book_details?isbn=${isbn}`)
        .then(response => response.json())
        .then(data => {
           
            const detailsDiv = document.getElementById('review-book-details');
            detailsDiv.innerHTML = `
                <p><strong>Title:</strong> ${data.title}</p>
                <p><strong>ISBN:</strong> ${data.isbn}</p>
                <p><strong>Publisher:</strong> ${data.publisher}</p>
                <p><strong>Ratings:</strong> ${data.average_rating} / 5</p>
                <form method="post" action="/submit_review">
                    <input type="hidden" name="isbn" value="${data.isbn}">
                    <textarea name="review_text" placeholder="Write your review here..." required></textarea>
                    <button type="submit" class="submit-review-btn">Submit Review</button>
                </form>
            `;
        });

    document.getElementById('reviews-modal').style.display = 'block';
}


function closeReviewModal() {
    
    document.getElementById('reviews-modal').style.display = 'none';
}

window.onclick = function(event) {
    let modal = document.getElementById('reviews-modal');
    if (event.target == modal) {
        modal.style.display = "none";
    }
}

let currentSlide = 0;

function moveSlide(step) {
    const slides = document.querySelectorAll('.carousel-item');
    const totalSlides = slides.length;
    currentSlide = (currentSlide + step + totalSlides) % totalSlides;
    const offset = -currentSlide * 220; 
    document.querySelector('.carousel-inner').style.transform = `translateX(${offset}px)`;
}


function addBooksToCarousel(books) {
    const carouselInner = document.querySelector('.carousel-inner');
    books.forEach(book => {
        const bookItem = document.createElement('div');
        bookItem.classList.add('carousel-item');
        bookItem.innerHTML = `<h4>${book.title}</h4><p>ISBN: ${book.isbn}</p>`;
        carouselInner.appendChild(bookItem);
    });
}


addBooksToCarousel([{title: 'Book 1', isbn: '123456'}, {title: 'Book 2', isbn: '654321'}]);



